@@ -1,4 +1,5 @@
-from yowsup.layers import YowLayerEvent, YowProtocolLayer
+from yowsup.common import YowConstants
+from yowsup.layers import YowLayerEvent, YowProtocolLayer, EventCallback
 from .keystream import KeyStream
 from yowsup.common.tools import TimeTools
 from .layer_crypt import YowCryptLayer
@@ -43,14 +44,14 @@ class YowAuthenticationProtocolLayer(YowProtocolLayer):
 
     def getUsername(self, full = False):
         if self._credentials:
-            return self._credentials[0] if not full else ("%s@s.whatsapp.net" % self._credentials[0])
+            return self._credentials[0] if not full else ("%s@%s" % (self._credentials[0], YowConstants.WHATSAPP_SERVER))
         else:
             prop = self.getProp(YowAuthenticationProtocolLayer.PROP_CREDENTIALS)
             return prop[0] if prop else None
-
-    def onEvent(self, event):
-        if event.getName() == YowNetworkLayer.EVENT_STATE_CONNECTED:
-            self.login()
+        
+    @EventCallback(YowNetworkLayer.EVENT_STATE_CONNECTED)
+    def onConnected(self, yowLayerEvent):
+        self.login()
 
     ## general methods
     def login(self):
