@@ -1,10 +1,9 @@
 from yowsup.common.http.warequest import WARequest
 from yowsup.common.http.waresponseparser import JSONResponseParser
-# from yowsup.env import CURRENT_ENV
 from yowsup.common.tools import StorageTools, WATools
 from yowsup.registration.existsrequest import WAExistsRequest
-from yowsup.env import S40YowsupEnv
-CURRENT_ENV = S40YowsupEnv()
+from yowsup.env import YowsupEnv
+import random, hashlib, os
 
 class WACodeRequest(WARequest):
 
@@ -22,9 +21,24 @@ class WACodeRequest(WARequest):
         self.addParam("lg", "en")
         self.addParam("sim_mcc", sim_mcc.zfill(3))
         self.addParam("sim_mnc", sim_mnc.zfill(3))
+        self.addParam("mcc", sim_mcc.zfill(3))
+        self.addParam("mnc", sim_mnc.zfill(3))
         self.addParam("method", method)
 
-        self.addParam("token", CURRENT_ENV.getToken(p_in))
+        self.addParam("mistyped", "6")
+        self.addParam("network_radio_type", "1")
+        self.addParam("simnum", "1")
+        self.addParam("s", "")
+        self.addParam("copiedrc", "1")
+        self.addParam("hasinrc", "1")
+        self.addParam("rcmatch", "1")
+        self.addParam("pid", int(random.uniform(100,9999)))
+        self.addParam("rchash", hashlib.sha256(os.urandom(20)).hexdigest())
+        self.addParam("anhash", os.urandom(20))
+        self.addParam("extexist", "1")
+        self.addParam("extstate", "1")
+
+        self.addParam("token", YowsupEnv.getCurrent().getToken(p_in))
 
         self.url = "v.whatsapp.net/v2/code"
 
@@ -47,4 +61,3 @@ class WACodeRequest(WARequest):
         if res["status"] == "sent":
             StorageTools.writeIdentity(self.cc + self.p_in, self.__id)
         return res
-
